/*
Sally Stanley and Frank Baumgartner
Replication file for 2020 Senior thesis
First, create a working directory and ensure it has these data files:
DS-Pros-year-county-top30.dta
DS-yearly.dta
DSRate-county-averages.dta
DP-Pros-Combined.dta

Last step: Change to that working directory:
*/
*cd f:\
cd G:\FB\teach\theses\SallyStanley\StanleyThesis-Dofile_data
clear


use DS-Pros-year-county-top30.dta
*Table 1 - (made in excel)

*Figure 1 - map top 30

*table 2 - correlation matrix
correlate deathsentences totalpop c_homt_p_new

*Figure 2 - (death sentences by homs)
collapse (sum) deathsentences c_homt_p_new , by(fips)

#delimit ;
twoway scatter deathsentences c_homt_p_new, mcolor(black)||
lfit deathsentences c_homt_p_new, mlstyle(color(gs0)) connect(line) ms(i) lcolor(black) lwidth(thick)  
graphregion(color(white)) 
ylabel(, nogrid)
legend(off)
xtitle("Homicides") 
ytitle("Death Sentences")
title("Death Sentences by Cumulative County Homicides", color(black) position(11) justification(left))
;


*Figure 3 (death sentences by pop)
clear
use DS-Pros-year-county-top30.dta
collapse (sum) deathsentences totalpop , by(fips)

#delimit ;
twoway scatter deathsentences totalpop, mcolor(black)||
lfit deathsentences totalpop, mlstyle(color(gs0)) connect(line) ms(i) lcolor(black) lwidth(thick)  
graphregion(color(white)) 
ylabel(, nogrid)
legend(off)
xtitle("Homicides") 
ytitle("Death Sentences")
title("Death Sentences by Cumulative County Homicides", color(black) position(11) justification(left))
;

*Figure 4 (prosecutors compared with others in same county)
clear
use DS-Pros-year-county-top30.dta
keep ds c_homt_p_new fips county state prosecutor
collapse (sum) ds c_homt_p_new (last) fips, by(prosecutor)
gen DSrateDA = (ds*100)/c_homt_p_new
rename ds DsTotalDA
gen HomsTotalDA = floor(c_homt_p_new)
drop c_homt_p_new
joinby fips using DSRate-county-averages.dta, unm(master)
sort fips prosecutor
order fips county state DsTotalCounty HomsTotalCounty DSrateCounty prosecutor DsTotalDA DSrateDA HomsTotalDA
drop _merge
gen DsTotalOtherDAs = DsTotalCounty - DsTotalDA
gen HomsTotalOtherDAs = HomsTotalCounty - HomsTotalDA 
gen DSRateOtherDAs = (DsTotalOtherDAs*100) / HomsTotalOtherDAs
gen DSRateDiff = DSrateDA - DSRateOtherDAs
gsort - DSRateDiff

gen Others= DSRateOtherDAs
corr DSRateOtherDAs DSrateDA
#delimit ;
scatter DSRateOtherDAs DSrateDA , mcolor(black)||
scatter DSRateOtherDAs Others, mlstyle(color(gs0)) connect(line) ms(i) lcolor(black) lwidth(thick)  
graphregion(color(white)) 
ylabel(, nogrid)
legend(off)
xtitle("Death Sentences (per 100 Homicides) for any Prosecutor") 
ytitle("Rate for Other Prosecutors from the same County")
title("Death Sentencing Rates for Individual Prosecutors" "Compared to other Prosecutors in the Same County", color(black) position(11) justification(left))
text(3.3 0.5 "Lower than others", placement(e) size())
text(1.5 3.8 "Higher than others", placement(e) size())
caption("Includes Top 30 Death Sentencing Counties in the US; N = 124; r = 0.47.", span)
;

*Figure 5 (national trends)
clear
use DS-yearly.dta

#delimit ;
graph twoway line deathsentences year if year > 1975,
graphregion(color(white)) 
ylabel(, nogrid)
legend(off)
xtitle("Year") 
ytitle("Death Sentences")
title("Total National Death Sentences", color(black) position(11) justification(left))
;

#delimit ;
graph twoway line D year if year > 1975,
graphregion(color(white)) 
ylabel(, nogrid)
legend(off)
xtitle("Year") 
ytitle("Death Sentencing Rate (Per 100 Homicides)")
title("National Death Sentencing Rate", color(black) position(11) justification(left))
;

*Figure 6 (Pinella, Pima, Hamilton, Hillsborough, OrangeFl, Clark, OrangeCa, Riverside, Oklahoma, Harris, Mobile)
*#23 Pinellas, FL
clear
*use DS-Pros-year-county-top30.dta
use DP-Pros-Combined.dta
#delimit ;
graph twoway line DSrate year if fips==12103,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(1993, lcolor(black) lstyle(solid))
text(30 1993.1  "McCabe" , place(e))
text(28.5 1993.1  "(2.06)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(30 1976.1  "Russell" , place(e))
text(28.5 1976.1  "(4.65)" , place(e))
title("Pinellas, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Pinellas.png, replace width(1950)

*#21 Pima, AZ
#delimit ;
graph twoway line DSrate year if fips==4019,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(1997, lcolor(black) lstyle(solid))
text(15 1997.1  "LaWall" , place(e))
text(14.3 1997.1  "(.87)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(15 1976.1  "Neely" , place(e))
text(14.3 1976.1  "(4.05)" , place(e))
title("Pima, AZ", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Pima.png, replace width(1950)

*#14 Hamilton, OH
#delimit ;
graph twoway line DSrate year if fips==39061,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2005, lcolor(black) lstyle(solid))
text(15 2005.1  "Deters" , place(e))
text(14.2 2005.1  "(1.98)" , place(e))
xline(1999, lcolor(black) lstyle(solid))
text(15 1999.1  "Allen" , place(e))
text(14.2 1999.1  "(.94)" , place(e))
xline(1992, lcolor(black) lstyle(solid))
text(15 1992.1  "Deters" , place(e))
text(14.2 1992.1  "(1.98)" , place(e))
xline(1984, lcolor(black) lstyle(solid))
text(15 1984.1  "Ney" , place(e))
text(14.2 1984.1  "(5.15)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(15 1976.1  "Leis" , place(e))
text(14.2 1976.1  "(2.67)" , place(e))
title("Hamilton, OH", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Hamilton.png, replace width(1950)

*#18 Hillsborough, FL
#delimit ;
graph twoway line DSrate year if fips==12057,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2001, lcolor(black) lstyle(solid))
text(8 2001.1  "Ober" , place(e))
text(7.6 2001.1  "(.76)" , place(e))
xline(1993, lcolor(black) lstyle(solid))
text(8 1993.1  "Coe" , place(e))
text(7.6 1993.1  "(1.93)" , place(e))
xline(1985, lcolor(black) lstyle(solid))
text(8 1985.1  "James" , place(e))
text(8 1989  "(3.32)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(8 1976.1  "Salcines" , place(e))
text(7.6 1976.1  "(2.34)" , place(e))
title("Hillsborough, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Hillsborough.png, replace width(1950)

*#26 Orange, FL
#delimit ;
graph twoway line DSrate year if fips==12095,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2013, lcolor(black) lstyle(solid))
text(10 2013.1  "Ashton" , place(e))
text(9.5 2013.1  "(.37)" , place(e))
xline(1989, lcolor(black) lstyle(solid))
text(10 1989.1  "Lamar" , place(e))
text(9.5 1989.1  "(1.40)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(10 1976.1  "Eagan" , place(e))
text(9.5 1976.1  "(3.18)" , place(e))
title("Orange, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-OrangeFL.png, replace width(1950)

*#7 Clark, NV
#delimit ;
graph twoway line DSrate year if fips==32003,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2012, lcolor(black) lstyle(solid))
text(10.1 2012.1  "Wolfson" , place(e))
text(9.5 2012.1  "(.80)" , place(e))
xline(2003, lcolor(black) lstyle(solid))
text(10.1 2003.1  "Roger" , place(e))
text(9.5 2003.1  "(1.07)" , place(e))
xline(1995, lcolor(black) lstyle(solid))
text(10.1 1995.1  "S. Bell" , place(e))
text(9.5 1995.1  "(2.32)" , place(e))
xline(1987, lcolor(black) lstyle(solid))
text(10.1 1987.1  "R. Bell" , place(e))
text(9.5 1988.1  "(4.32)" , place(e))
xline(1979, lcolor(black) lstyle(solid))
text(10.1 1979.1  "Miller" , place(e))
text(9.5 1979.1  "(3.52)" , place(e))
title("Clark, NV", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Clark.png, replace width(1950)

*#13 Orange, CA
#delimit ;
graph twoway line DSrate year if fips==6059,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(1999, lcolor(black) lstyle(solid))
text(10 1999.1  "Rackauckas" , place(e))
text(9.4 1999.1  "(2.76)" , place(e))
xline(1990, lcolor(black) lstyle(solid))
text(10 1990.1  "Capizzi" , place(e))
text(9.4 1990.1  "(1.49)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(10 1976.1  "Hicks" , place(e))
text(9.4 1976.1  "(1.87)" , place(e))
title("Orange, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Orange.png, replace width(1950)

*#10 Riverside, CA 
#delimit ;
graph twoway line DSrate year if fips==6065,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2015, lcolor(black) lstyle(solid))
text(10 2015.1  "Hestrin" , place(e))
text(9.4 2015.1  "(4.68)" , place(e))
xline(2011, lcolor(black) lstyle(solid))
text(10 2011.1  "Zell." , place(e))
text(9.4 2011.1  "(4.46)" , place(e))
xline(2007, lcolor(black) lstyle(solid))
text(10 2007  "Pach." , place(e))
text(9.4 2007  "(4.46)" , place(e))
xline(1983, lcolor(black) lstyle(solid))
text(10 1983.1  "Trask" , place(e))
text(9.4 1983.1  "(2.14)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(10 1976.1  "Morton" , place(e))
text(9.4 1976.1  "(1.10)" , place(e))
title("Riverside, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Riverside.png, replace width(1950)

*#8 Oklahoma, OK
#delimit ;
graph twoway line DSrate year if fips==40109,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2007, lcolor(black) lstyle(solid))
text(10 2007.1  "Prater" , place(e))
text(9.4 2007.1  "(1.52)" , place(e))
xline(2002.1, lcolor(black) lstyle(solid))
text(10 2002.1  "Lane" , place(e))
text(9.4 2002.1  "(4.49)" , place(e))
xline(1980, lcolor(black) lstyle(solid))
text(10 1980.1  "Macy" , place(e))
text(9.4 1980.1  "(4.15)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(10 1976.1  "Coats" , place(e))
text(9.4 1976.1  "(3.22)" , place(e))
title("Oklahoma, OK", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Oklahoma.png, replace width(1950)

* #2 Harris, TX (excluded Magidson only serving 2008)
#delimit ;
graph twoway line DSrate year if fips==48201,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2013, lcolor(black) lstyle(solid))
text(4 2013.1  "Anderson" , place(e))
text(3.8 2013.1  "(.37)" , place(e))
xline(2009, lcolor(black) lstyle(solid))
text(4 2009.1  "Lykos" , place(e))
text(3.8 2009.1  "(.37)" , place(e))
xline(2001, lcolor(black) lstyle(solid))
text(4 2001.1  "Rosenthal" , place(e))
text(3.8 2001.1  "(1.51)" , place(e))
xline(1980, lcolor(black) lstyle(solid))
text(4 1980.1  "Holmes" , place(e))
text(3.8 1980.1  "(1.75)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(4 1976.1  "Vance" , place(e))
text(3.8 1976.1  "(.817)" , place(e))
title("Harris, TX", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Harris.png, replace width(1950)

*#29 Mobile, AL
#delimit ;
graph twoway line DSrate year if fips==1097,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2011, lcolor(black) lstyle(solid))
text(6 2011.1  "Rich" , place(e))
text(5.7 2011.1  "(2.78)" , place(e))
xline(1995, lcolor(black) lstyle(solid))
text(6 1995.1  "Tyson" , place(e))
text(5.7 1995.1  "(1.18)" , place(e))
xline(1979, lcolor(black) lstyle(solid))
text(6 1979.1  "Galanos" , place(e))
text(5.7 1979.1  "(1.36)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(6 1976.1  "Gra." , place(e))
text(5.7 1976.1  "(3.3)" , place(e))
title("Mobile, AL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Mobile.png, replace width(1950)


*Figure 7 (Alameda, Orleans, Bexar, Cuyahoga, Miami, Philadelphia)
*#24 Alameda, CA
#delimit ;
graph twoway line DSrate year if fips==6001,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2010, lcolor(black) lstyle(solid))
text(4 2010.1  "O'Malley" , place(e))
text(3.8 2010.1  "(.36)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(4 1976.1  "Orloff" , place(e))
text(3.8 1976.1  "(1.25)" , place(e))
title("Alameda, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Alameda.png, replace width(1950)

*#25 Orleans, LA
#delimit ;
graph twoway line DSrate year if fips==22071,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2009, lcolor(black) lstyle(solid))
text(2.5 2009.1  "Cannizzaro" , place(e))
text(2.4 2009.1  "(.05)" , place(e))
xline(2003, lcolor(black) lstyle(solid))
text(2.5 2003.1  "Jordan" , place(e))
text(2.4 2003.1  "(0.0)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(2.5 1976.1  "Connick" , place(e))
text(2.4 1976.1  "(.53)" , place(e))
title("Orleans, LA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Orleans.png, replace width(1950)

*#17 Bexar, TX 
#delimit ;
graph twoway line DSrate year if fips==48029,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2015, lcolor(black) lstyle(solid))
text(6 2015.1  "LaHood" , place(e))
text(5.7 2015.1  "(.41)" , place(e))
xline(1999, lcolor(black) lstyle(solid))
text(6 1999.1  "Reed" , place(e))
text(5.7 1999.1  "(1.35)" , place(e))
xline(1991, lcolor(black) lstyle(solid))
text(6 1991.1  "Hillbig" , place(e))
text(5.7 1991.1  "(1.62)" , place(e))
xline(1987, lcolor(black) lstyle(solid))
text(6 1987.1  "Rodr." , place(e))
text(5.7 1987.1  "(.90)." , place(e))
xline(1983, lcolor(black) lstyle(solid))
text(6 1983.1  "Mills." , place(e))
text(5.7 1983.1  "(.48)." , place(e))
xline(1977, lcolor(black) lstyle(solid))
text(6 1977.1  "White" , place(e))
text(5.7 1977.1  "(1.07)" , place(e))
title("Bexar, TX", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Bexar.png, replace width(1950)

*#12 Cuyahoga, OH
#delimit ;
graph twoway line DSrate year if fips==39035,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2013, lcolor(black) lstyle(solid))
text(4 2013.1  "McGinty" , place(e))
text(3.8 2013.1  "(.27)" , place(e))
xline(1999, lcolor(black) lstyle(solid))
text(4 1999.3  "Mason" , place(e))
text(3.8 1999.3  "(.61)" , place(e))
xline(1991, lcolor(black) lstyle(solid))
text(4 1991.1  "Jones" , place(e))
text(3.8 1991.1  "(1.35)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(4 1976.1  "Corrigan" , place(e))
text(3.8 1976.1  "(1.64)" , place(e))
title("Cuyahoga, OH", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Cuyahoga.png, replace width(1950)

*#6 Miami, FL (Gerstein excluded)
#delimit ;
graph twoway line DSrate year if fips==12086,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(1993, lcolor(black) lstyle(solid))
text(2.5 1993.1  "Rundle" , place(e))
text(2.4 1993.1  "(.58)" , place(e))
xline(1978, lcolor(black) lstyle(solid))
text(2.5 1978.1  "Reno" , place(e))
text(2.4 1978.1  "(1.07" , place(e))
title("Miami-Dade, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Miami.png, replace width(1950)

*#3 Philadelphia, PA (took out fitzpatrick)
#delimit ;
graph twoway line DSrate year if fips==42101,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2010, lcolor(black) lstyle(solid))
text(4 2010.1  "Williams" , place(e))
text(3.8 2010.1  "(.18)" , place(e))
xline(1991, lcolor(black) lstyle(solid))
text(4 1991.1  "Abraham" , place(e))
text(3.8 1991.1  "(1.42)" , place(e))
xline(1986, lcolor(black) lstyle(solid))
text(4 1986.1  "Castille" , place(e))
text(3.8 1986.1  "(2.26)" , place(e))
xline(1978, lcolor(black) lstyle(solid))
text(4 1978.1  "Rendell" , place(e))
text(3.8 1978.1  "1.06" , place(e))
title("Philadelphia, PA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Philly.png, replace width(1950)

*Figure 8 (Cook, Maricopa, Jefferson, Dallas)
*#5 Cook, IL (took our partee from 89-90)
#delimit ;
graph twoway line DSrate year if fips==17031,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2009, lcolor(black) lstyle(solid))
text(2 2009.1  "Alvarez" , place(e))
text(1.9 2009.1  "(0.0)" , place(e))
xline(1997, lcolor(black) lstyle(solid))
text(2 1997.1  "Devine" , place(e))
text(1.9 1997.1  "(.28)" , place(e))
xline(1991, lcolor(black) lstyle(solid))
text(2 1991.1  "O'Malley" , place(e))
text(1.9 1991.1  "(.48)" , place(e))
xline(1981, lcolor(black) lstyle(solid))
text(2 1981.1  "Daley" , place(e))
text(1.9 1981.1  "(.92)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(2 1976.1  "Carey" , place(e))
text(1.9 1976.1  "(.37)" , place(e))
title("Cook, IL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Cook.png, replace width(1950)

*#4 Maricopa, AZ (Romley excluded)
#delimit ;
graph twoway line DSrate year if fips==4013,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2011, lcolor(black) lstyle(solid))
text(5 2011.1  "Montgomery" , place(e))
text(4.79 2011.1  "(.96)" , place(e))
xline(2005, lcolor(black) lstyle(solid))
text(5 2005.1  "Thomas" , place(e))
text(4.79 2005.1  "(1.63)" , place(e))
xline(1989, lcolor(black) lstyle(solid))
text(5 1989.1  "Romley" , place(e))
text(4.79 1989.1  "(1.55)" , place(e))
xline(1981, lcolor(black) lstyle(solid))
text(5 1981.1  "Collins" , place(e))
text(4.79 1981.1  "(2.69)" , place(e))
xline(1977, lcolor(black) lstyle(solid))
text(5 1977.1  "Hyder" , place(e))
text(4.79 1977.1  "(2.28)" , place(e))
title("Maricopa, AZ", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Maricopa.png, replace width(1950)

*#16 Jefferson, AL
#delimit ;
graph twoway line DSrate year if fips==1073,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2009, lcolor(black) lstyle(solid))
text(4 2009.1  "Falls" , place(e))
text(3.8 2009.1  "(.81)" , place(e))
xline(1985, lcolor(black) lstyle(solid))
text(4 1985.1  "Barber" , place(e))
text(3.8 1985.1  "(1.48)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(4 1976.1  "Morgan" , place(e))
text(3.8 1976.1  "(1.62)" , place(e))
title("Jefferson, AL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Jefferson.png, replace width(1950)

*#11 Dallas, TX
#delimit ;
graph twoway line DSrate year if fips==48113,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2015, lcolor(black) lstyle(solid))
text(3 2015.1  "Hawk" , place(e))
text(2.85 2015.1  "(0.0)" , place(e))
xline(2007, lcolor(black) lstyle(solid))
text(3 2007.1  "Watkins" , place(e))
text(2.85 2007.1  "(.55)" , place(e))
xline(1999, lcolor(black) lstyle(solid))
text(3 1999.3  "Hill" , place(e))
text(2.85 1999.3  "(1.23)" , place(e))
xline(1987, lcolor(black) lstyle(solid))
text(3 1987.1  "Vance" , place(e))
text(2.85 1987.1  "(.82)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(3 1976.1  "Wade" , place(e))
text(2.85 1976.1  "(.53)" , place(e))
title("Dallas, TX", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Dallas.png, replace width(1950)

*Figure 9 (San Bernardino, Tarrant, Shelby, San Diego, Sacramento, LA, Polk, Duval)
*#22 San Bernardino, CA
#delimit ;
graph twoway line DSrate year if fips==6071,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2003, lcolor(black) lstyle(solid))
text(5 2003.1  "Ramos" , place(e))
text(4.75 2003.1  "(.81)" , place(e))
xline(1995, lcolor(black) lstyle(solid))
text(5 1995.1  "Stout" , place(e))
text(4.75 1995.1  "(1.37)" , place(e))
xline(1981, lcolor(black) lstyle(solid))
text(5 1981.1  "Kottmeier" , place(e))
text(4.75 1981.1  "(.76)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(5 1976.1  "Cramer" , place(e))
text(4.75 1976.1  "(.93)" , place(e))
title("San Bernardino, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-SanBernardino.png, replace width(1950)

*#20 Tarrant, TX
#delimit ;
graph twoway line DSrate year if fips==48439,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2015, lcolor(black) lstyle(solid))
text(6 2015.1  "Wilson" , place(e))
text(5.7 2015.1  "(.52)" , place(e))
xline(2009, lcolor(black) lstyle(solid))
text(6 2009.1  "Shannon" , place(e))
text(5.7 2009.1  "(.98)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(6 1976.1  "Curry" , place(e))
text(5.7 1976.1  "(1.45)" , place(e))
title("Tarrant, TX", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Tarrant.png, replace width(1950)

*#19 Shelby, TN
#delimit ;
graph twoway line DSrate year if fips==47157,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2011, lcolor(black) lstyle(solid))
text(4 2011.1  "Weirich" , place(e))
text(3.8 2011.1  "(.32)" , place(e))
xline(1997, lcolor(black) lstyle(solid))
text(4 1997.1  "Gibbons" , place(e))
text(3.8 1997.1  "(.98)" , place(e))
xline(1990, lcolor(black) lstyle(solid))
text(4 1990.1  "Pierrotti" , place(e))
text(3.8 1990.1  "(1.21)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(4 1976.1  "Stanton" , place(e))
text(3.8 1976.1  "(1.25)" , place(e))
title("Shelby, TN", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Shelby.png, replace width(1950)

*#28 San Diego, CA

#delimit ;
graph twoway line DSrate year if fips==6073,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2003, lcolor(black) lstyle(solid))
text(2.5 2005.1  "Dumanis" , place(e))
text(2.38 2005.3  "(.74)" , place(e))
xline(1995, lcolor(black) lstyle(solid))
text(2.5 1995.1  "Pfing." , place(e))
text(2.38 1995.1  "(1.06)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(2.5 1976.1  "Miller" , place(e))
text(2.38 1976.1  "(.69)" , place(e))
title("San Diego, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-SanDiego.png, replace width(1950)

*#27 Sacramento, CA
#delimit ;
graph twoway line DSrate year if fips==6067,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2015, lcolor(black) lstyle(solid))
text(6 2015.1  "Schubert" , place(e))
text(5.7 2015.1  "(0.00)" , place(e))
xline(1995, lcolor(black) lstyle(solid))
text(6 1996.3  "Scully" , place(e))
text(5.7 1996.3  "(1.16)" , place(e))
xline(1990, lcolor(black) lstyle(solid))
text(6 1990.1  "White" , place(e))
text(5.7 1990.1  "(1.36)" , place(e))
xline(1983, lcolor(black) lstyle(solid))
text(6 1983.1  "Daugherty" , place(e))
text(5.7 1983.1  "(2.26)" , place(e))
xline(1979, lcolor(black) lstyle(solid))
text(6 1979.1  "Jacks." , place(e))
text(5.7 1979.1  "(1.94)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(6 1976.1  "Pric." , place(e))
text(5.7 1976.1  "(.38)" , place(e))
title("Sacramento, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Sacramento.png, replace width(1950)

* #1 Los Angeles (Excluded Philibosinian)
#delimit ;
graph twoway line DSrate year if fips==6037,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2013, lcolor(black) lstyle(solid))
text(1.5 2013.1  "Lacey" , place(e))
text(1.4 2013.1  "(.38)" , place(e))
xline(2001, lcolor(black) lstyle(solid))
text(1.5 2001.1  "Cooley" , place(e))
text(1.4 2001.1  "(.55)" , place(e))
xline(1993, lcolor(black) lstyle(solid))
text(1.5 1993.1  "Garcetti" , place(e))
text(1.4 1993.1  "(.77)" , place(e))
xline(1985, lcolor(black) lstyle(solid))
text(1.5 1985.1  "Reiner" , place(e))
text(1.4 1985.1  ".51)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(1.5 1976.1  "Van De Kamp" , place(e))
text(1.4 1976.1  "(.41)" , place(e))
title("Los Angeles, CA", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-LosAngeles.png, replace width(1950)

*#30 Polk, FL
#delimit ;
graph twoway line DSrate year if fips==12105,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(1985, lcolor(black) lstyle(solid))
text(15 1985.1  "Hill" , place(e))
text(14.2 1985.1  "(3.13)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(15 1976.1  "Yancey" , place(e))
text(14.2 1976.1  "(2.87)" , place(e))
title("Polk, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Polk.png, replace width(1950)

*#9 Duval, FL
#delimit ;
graph twoway line DSrate year if fips==12031,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(2009, lcolor(black) lstyle(solid))
text(6.1 2009.1  "Corey" , place(e))
text(5.8 2009.1  "(2.46)" , place(e))
xline(1991, lcolor(black) lstyle(solid))
text(6.1 1991.1  "Shorstein" , place(e))
text(5.8 1991.1  "(2.37)" , place(e))
xline(1976, lcolor(black) lstyle(solid))
text(6.1 1976.1  "Austin" , place(e))
text(5.8 1976.1  "(1.98)" , place(e))
title("Duval, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Duval.png, replace width(1950)

*Figure 10 (Broward)
*#15 Broward, FL
#delimit ;
graph twoway line DSrate year if fips==12011,
graphregion(color(white)) 
lcolor(black) lwidth(thick) lstyle(solid)
ylabel(, nogrid)
yscale() 
ylabel()
ytitle("Death Sentences per 100 Homicides") 
xscale()
xlabel()
xtitle("")
xline(1977, lcolor(black) lstyle(solid))
text(5 1977.1  "Satz" , place(e))
text(4.7 1977.1  "1.85" , place(e))
title("Broward, FL", color(black) position(11) justification(left))
caption("")
;
graph export DS-Rate-by-Prosecutor-Broward.png, replace width(1950)

*TABLE 2 (regression pg. 38 and continued on pg. 46 in appendix)

*Calculate years of service for DA's
clear
use DP-Pros-Combined.dta
tab prosecutor
contract prosecutor, freq(DAYears)
drop if DAYears>100000
joinby prosecutor using DP-Pros-Combined.dta, unm(both)
save DP-Pros-Combined-Years.dta, replace
***Switch now to making the regressions:
*First, the baseline model for all US counties with the option of the death penalty

/* Don't need to do these variable generations because the resulting file is below:
clear
use DS-Pros-year-county-top30.dta
*use DP-Pros-Combined-Years.dta
*set panel
xtset fips year

*create lagged homicide count
gen hom_lag= l.c_homt_p_new

*create homicide rate
gen homrate = (c_homt_p_new / totalpop)*1000

*create lagged homicide rate
gen homrate_lag= l.homrate

*** Keep obs only for years when state has the death penalty  
keep if legal==1

*Keeping data from 1976-present
keep if year>=1976
keep if year<=2016

*created logged version of population
gen totalpop_log = log(totalpop)

*create binary for partisan elections
gen partisanelection = (selection_method==1)

*create binary for republican governor
gen repgov = (governor_party==0)

*create percent republican control of legislature
gen repleg = (sen_rep_in_sess + hs_rep_in_sess) / (sen_tot_in_sess + hs_tot_in_sess)

*create squared percent black 
gen black2 = percent_black*percent_black

*adjust scale
gen hom = hom_lag/100
gen violent = violent_rate/100
gen threat2 = threat/100
replace cumulative_deathsentences = cumulative_deathsentences/10
replace poverty = poverty/10
replace citi = citi/100
replace lynching_SRTB = lynching_SRTB/100

*create threat*lynching interaction variables
gen threat_lynching = threat2 * lynching_SRTB

*create year dummies
tabulate year, generate(y)

*same for DA's
sort prosecutor
tabulate prosecutor, generate(DANumber)
sum DANumber*

rename DS NationalDS
save DS-Pros-year-county.dta, replace
*save only the 30 high-use counties
drop if _merge !=3
save DS-Pros-year-county-top30.dta, replace
*/
*** Models ***

clear
use DS-Pros-year-county-top30.dta
reg ds hom totalpop_log cumulative_deathsentences threat2 poverty citi6016 lynching_SRTB  partisanelection repgov south 
reg ds hom totalpop_log cumulative_deathsentences threat2 poverty  NationalDS
est sto m11
reg ds hom totalpop_log cumulative_deathsentences threat2 poverty NationalDS i.fips  
est sto m12
reg ds hom totalpop_log cumulative_deathsentences threat2 poverty NationalDS i.fips  if DAYears>3
est sto m13
reg ds hom totalpop_log cumulative_deathsentences threat2 poverty NationalDS i.fips DANumber1-DANumber123 if DAYears>3
est sto m14
esttab m11 m12 m13 m14 using "combined-ols.rtf", mtitle("Baseline" "County Fixed Effects" "DAs with 4 years of service" "DA Included" ) b t star r2 obslast rtf replace


